@@ -412,7 +412,7 @@ int main(int argc, char **argv){
     free(bitmap);   /// free bitmp
     if(opt.ncurses)
 	close_ncurses();
-    printf("Successfully cloned.\n");
+    printf("Cloned successfully.\n");
     if(opt.debug)
 	close_log();
     return 0;	    /// finish
